Changelog
---------

0.9.1 (2019-03-22)
~~~~~~~~~~~~~~~~~~~

- Fixes organization fields in the vCard export.
  [msom]

0.9.0 (2019-02-18)
~~~~~~~~~~~~~~~~~~~

- Adds parliamentary groups to people.
  [msom]

0.8.1 (2019-02-05)
~~~~~~~~~~~~~~~~~~~

- Specifies the charset for certain fields in the vCard export.
  [msom]

0.8.0 (2019-02-04)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to sort suborganizations.
  [msom]

0.7.1 (2018-11-23)
~~~~~~~~~~~~~~~~~~~

- Adds compatibility with onegov.core 0.74.3.
  [msom]

0.7.0 (2018-11-14)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to move memberships of an agency.
  [msom]

0.6.4 (2018-11-13)
~~~~~~~~~~~~~~~~~~~

- Adds the spoken name to the elasticsearch suggestions.
  [msom]

0.6.3 (2018-11-12)
~~~~~~~~~~~~~~~~~~~

- Fixes Pep8 issue.
  [msom]

0.6.2 (2018-11-12)
~~~~~~~~~~~~~~~~~~~

- Simplifies adding a person to an agency.
  [msom]

0.6.1 (2018-11-09)
~~~~~~~~~~~~~~~~~~~

- Removes the saluation from the spoken title and vCard.
  [msom]

0.6.0 (2018-11-09)
~~~~~~~~~~~~~~~~~~~

- Adds additional columns to people.
  [msom]

0.5.0 (2018-11-08)
~~~~~~~~~~~~~~~~~~~

- Adds vCards to people.
  [msom]

0.4.0 (2018-10-29)
~~~~~~~~~~~~~~~~~~~

- Adds agencies and memberships.
  [msom]

- Enables polymorphic subclasses of people.
  [msom]

- Adds content and meta columns to people.
  [msom]

- Requires Python 3.6.
  [href]

- Refactors the package.
  [msom]

0.3.0 (2017-09-26)
~~~~~~~~~~~~~~~~~~~

- Switches to onegov.search's automatic language detection.
  [href]

0.2.0 (2017-06-22)
~~~~~~~~~~~~~~~~~~~

- Changes Elasticsearch 2.x mappings from string to text/keyword.
  [href]

0.1.2 (2015-12-31)
~~~~~~~~~~~~~~~~~~~

- Adds an extra notes field for people.
  [href]

0.1.1 (2015-10-22)
~~~~~~~~~~~~~~~~~~~

- Removes the salutation from the title and puts the last name first.
  [href]

0.1.0 (2015-10-12)
~~~~~~~~~~~~~~~~~~~

- Removes Python 2.x support.
  [href]

0.0.6 (2015-09-25)
~~~~~~~~~~~~~~~~~~~

- Adds onegov.search integration.
  [href]

0.0.5 (2015-09-10)
~~~~~~~~~~~~~~~~~~~

- No longer raise an error if the provided id is not a uuid.
  [href]

0.0.4 (2015-09-03)
~~~~~~~~~~~~~~~~~~~

- Adds a function field to the person.
  [href]

0.0.3 (2015-08-24)
~~~~~~~~~~~~~~~~~~~

- Adds compatibility with onegov.core 0.4.25
  [href]

0.0.2 (2015-08-18)
~~~~~~~~~~~~~~~~~~~

- Renames 'academic_title' to the more general 'salutation'. This requires
  a onegov-core upgrade run to migrate existing databases.
  [href]

- Removes Gravatar support.
  [href]

0.0.1 (2015-07-03)
~~~~~~~~~~~~~~~~~~~

- Initial Release
